//
//  IGLocation.h
//  Ingeo
//
//  Created by Amit Palomo on 8/17/14.
//
//

#import <Foundation/Foundation.h>
#import <CoreLocation/CoreLocation.h>

/**
 The IGMotionState enum holds all possible user motion states
 */
typedef NS_ENUM(NSInteger, IGMotionState) {
    IGMotionStateUknown          = -1,
    IGMotionStateStanding        = 0,
    IGMotionStateStartedMoving   = 1,
    IGMotionStateMovingSlow      = 2,
    IGMotionStateMovingFast      = 3,
};

/** IGLocation is a CLLocation subclass with additional information generated by IngeoSDK.
 A IGLocation object represents the location data generated by a IGLocationManager object.
 This object incorporates the geographical coordinates and altitude of the device’s location
 along with values indicating the accuracy of the measurements and when those measurements were made.
 The user Motion State (see `motionState`) provided by IGLocation represents the physical activity of
 the user (Standing, Started Moving, Moving Slow or Moving Fast) while this measurements were made.
 */

@interface IGLocation : CLLocation

///---------------------------------------------------------------------------------------
/// @name ￼Initialize
///---------------------------------------------------------------------------------------

/**
 Initializes and returns an instance of IGLocation with the specified CLLocation object and motionState.

 Typically, you acquire IGLocation objects from the IGLocationManager service, but you can use this method to create new IGLocation objects for other uses in your application.
 
 @param clLocation input IGLocation object
 @param state motion state to be registered into the resulting IGLocation object
 */
+ (IGLocation *)igLocationFromCLLocation:(CLLocation *)clLocation andMotionState:(IGMotionState)state;

///---------------------------------------------------------------------------------------
/// @name Location Attributes
///---------------------------------------------------------------------------------------

/**
 Returns the timestamp when this location was determined in unix time format (epoch)
 */
@property(readonly, nonatomic) NSTimeInterval unixTimestamp;

/**
 Returns the latitude of the location (in degrees)
 */
@property(readonly, nonatomic) double latitude;

/**
 Returns the longitude of the location (in degrees)
 */

@property(readonly, nonatomic) double longitude;

/**
 Returns the speed of the location in meters per second. Negative if speed is invalid.
 
 speed attribute provided by IGLocation is far more accurate than speed attribue provided by Apple's CLLocation
 */
@property(readonly, nonatomic) CLLocationSpeed speed;

/**
 True if IGLocation object was created during background app mode
 */
@property(readonly, nonatomic) BOOL createdInBG;

/**
 The user's motion state on which this location was generated
 */
@property(readonly, nonatomic) IGMotionState motionState;

///---------------------------------------------------------------------------------------
/// @name ￼Helper Methods
///---------------------------------------------------------------------------------------

/**
 Convinient method to retrieve a describing string from a IGMotionState numeric value
 
 @param motion IGMotionState
*/
+ (NSString *)stringForMotionState:(IGMotionState)motion;

@end